summaryrefslogtreecommitdiffstats
path: root/kio/misc/uiserver.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kio/misc/uiserver.cpp')
-rw-r--r--kio/misc/uiserver.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kio/misc/uiserver.cpp b/kio/misc/uiserver.cpp
index 44fb8af19..2ce91feb3 100644
--- a/kio/misc/uiserver.cpp
+++ b/kio/misc/uiserver.cpp
@@ -1378,10 +1378,10 @@ UIServer* UIServer::createInstance()
extern "C" KDE_EXPORT int kdemain(int argc, char **argv)
{
KLocale::setMainCatalogue("kdelibs");
// GS 5/2001 - I changed the name to "KDE" to make it look better
// in the titles of dialogs which are displayed.
- KAboutData aboutdata("kio_uiserver", I18N_NOOP("KDE"),
- "0.8", I18N_NOOP("KDE Progress Information UI Server"),
+ KAboutData aboutdata("kio_uiserver", I18N_NOOP("TDE"),
+ "0.8", I18N_NOOP("TDE Progress Information UI Server"),
KAboutData::License_GPL, "(C) 2000, David Faure & Matt Koss");
// Who's the maintainer ? :)
aboutdata.addAuthor("David Faure",I18N_NOOP("Developer"),"faure@kde.org");
@@ -1378,10 +1378,10 @@ UIServer* UIServer::createInstance()
{
KLocale::setMainCatalogue("kdelibs");
- // GS 5/2001 - I changed the name to "KDE" to make it look better
+ // GS 5/2001 - I changed the name to "TDE" to make it look better
// in the titles of dialogs which are displayed.